@@ -1,12 +1,12 @@
-from .profile import *
-from .core import git_id
+from git_id.profile import *
+from git_id.core import main
 
 __copyright__ = 'Copyright (C) 2020 Yuichiro Smith'
-__version__ = '0.1.0'
+__version__ = '1.1.0'
 __license__ = 'MIT License'
 __author__ = 'Yuichiro Smith'
 __author_email__ = 'contact@yu-smith.com'
 __url__ = 'http://github.com/yu-ichiro/git-id'
 
 if __name__ == "__main__":
-    git_id()
+    main()
